@@ -5,11 +5,24 @@ import requests
 
 
 class TelegramLogger:
+    """
+
+    - Visit `https://api.telegram.org/bot<token>/getUpdates` to get `chat_id`.
+
+    Example:
+        >>> import os
+        >>> os.environ["TELEGRAM_BOT_TOKEN"] = "####"
+        >>> os.environ["TELEGRAM_BOT_CHAT_ID"] = "####"
+        >>> bot = stvh.misc.TelegramLogger(callback=print)
+        >>> bot.send("Hello, world!")
+        Hello, world!
+    """
+
     def __init__(
         self,
-        token: str,
-        chat_id: str,
-        callback: Optional[Callable[[str], Any]],
+        token: Optional[str] = None,
+        chat_id: Optional[str] = None,
+        callback: Optional[Callable[[str], Any]] = None,
     ) -> None:
         """TODO
 
@@ -17,12 +30,17 @@ class TelegramLogger:
             token (str):
             chat_id (str):
         """
+        import os
+
+        token = os.getenv("TELEGRAM_BOT_TOKEN", default="") if token is None else token
+        chat_id = os.getenv("TELEGRAM_BOT_CHAT_ID", default="") if chat_id is None else chat_id
+
         self._url: str = f"https://api.telegram.org/bot{token}/sendMessage"
         self._chat_id: str = chat_id
         self._callback: Optional[Callable[[str], Any]] = callback
         self._msgs: list[str] = []
 
-    def add(self, msg: str) -> None:
+    def add(self, msg: str = "") -> None:
         """TODO
 
         Args:
@@ -48,7 +66,7 @@ class TelegramLogger:
         resp.raise_for_status()  # what is the purpose of this line?
         del self._msgs[:]
 
-    def send(self, msg: str) -> None:
+    def send(self, msg: str = "") -> None:
         """TODO
 
         Args:
@@ -58,7 +76,7 @@ class TelegramLogger:
         self.flush()
 
     @staticmethod
-    def format_msg(msg: str) -> str:
+    def format_msg(msg: str = "") -> str:
         """TODO
 
         Args:
